==> carbon-components-react-0.0.7.tgz: package/es/components/ResourceHeader/ResourceHeader.js <==
import React from 'react';
import PropTypes from 'prop-types';
import classNames from 'classnames';
import Button from '../Button';
import { Tools16, Stop16, Restart16 } from '@rocketsoftware/icons-react';

function renderActionButtons(type, onClick) {
  var stop = Stop16;
  var reboot = Restart16;
  var maintenance = Tools16;
  var svg;

  if (type === 'Stop') {
    svg = stop;
    return React.createElement(Button, {
      className: "bx--resource-header__button",
      onClick: onClick,
      small: true,
      renderIcon: svg,
      kind: "ghost"
    }, type);
  } else if (type === 'Reboot') {
    svg = reboot;
    return React.createElement(Button, {
      className: "bx--resource-header__button",
      onClick: onClick,
      renderIcon: svg,
      small: true,
      kind: "ghost"
    }, type);
  } else if (type === 'Maintenance') {
    svg = maintenance;
    return React.createElement(Button, {
      className: "bx--resource-header__button",
      onClick: onClick,
      small: true,
      renderIcon: svg,
      kind: "ghost"
    }, type);
  }
} // function renderTitleStatus() {
//   return (
//     <div className="bx--resource-header__status-item bx--resource-header__status-item--active">
//       Active
//     </div>
//   );
// }


function renderStatus(status) {
  return status.map(function (item, i) {
    var statusClasses = classNames({
      'bx--resource-header__status-item--active': item.isTrue
    }, 'bx--resource-header__status-item');
    return React.createElement("div", {
      key: i,
      className: statusClasses
    }, item.text);
  });
}

var ResourceHeader = function ResourceHeader(_ref) {
  var className = _ref.className,
      icon = _ref.icon,
      isActive = _ref.isActive,
      renderActions = _ref.renderActions,
      renderBreadcrumbs = _ref.renderBreadcrumbs,
      renderMaintenance = _ref.renderMaintenance,
      renderReboot = _ref.renderReboot,
      renderStop = _ref.renderStop,
      status = _ref.status,
      subtitle = _ref.subtitle,
      title = _ref.title;
  var resourceHeaderClasses = classNames('bx--resource-header', className);
  return React.createElement("header", {
    className: resourceHeaderClasses
  }, React.createElement("section", {
    className: "bx--resource-header__container"
  }, React.createElement("div", {
    className: "bx--resource-header__container--left"
  }, renderBreadcrumbs && renderBreadcrumbs(), React.createElement("div", {
    className: "bx--resource-header__content-container"
  }, icon && React.createElement("div", {
    className: "bx--resource-header__icon"
  }, icon), React.createElement("div", {
    className: "bx--resource-header__content"
  }, title && React.createElement("div", {
    className: "bx--resource-header__title"
  }, React.createElement("h3", null, title), isActive && React.createElement("div", {
    className: "bx--resource-header__status-item bx--resource-header__status-item--active"
  }, "Active")), React.createElement("div", {
    className: "bx--resource-header__subtitle"
  }, subtitle && subtitle.map(function (item, key) {
    return React.createElement("span", {
      key: key
    }, item, " \xA0");
  }))))), React.createElement("div", {
    className: "bx--resource-header__container--right"
  }, React.createElement("div", {
    className: "bx--resource-header__status"
  }, status && renderStatus(status)), React.createElement("div", {
    className: "bx--resource-header__actions"
  }, renderStop && renderActionButtons('Stop', renderStop), renderReboot && renderActionButtons('Reboot', renderReboot), renderMaintenance && renderActionButtons('Maintenance', renderMaintenance), renderActions && renderActions()))));
};

ResourceHeader.propTypes = {
  /**
   * The CSS class names of the resource header
   */
  className: PropTypes.string,

  /**
   * The icon to be rendered in the header.
   */
  icon: PropTypes.node,

  /**
   * `true` to show the status text next to the resource header title.
   */
  isActive: PropTypes.bool,

  /**
   * The function used to create and show an action dropdown.
   */
  renderActions: PropTypes.func,

  /**
   * The function used to create and show breadcrumbs.
   */
  renderBreadcrumbs: PropTypes.func,

  /**
   * The function used to show and attach actions to the maintenance icon
   */
  renderMaintenance: PropTypes.func,

  /**
   * The function used to show and attach actions to the reboot icon
   */
  renderReboot: PropTypes.func,

  /**
   * The function used to show and attach actions to the stop icon
   */
  renderStop: PropTypes.func,

  /**
   * The array used to show status text above the action icons
   */
  status: PropTypes.array,

  /**
   * The array used to show subtitle text below the resource header title
   */
  subtitle: PropTypes.array,

  /**
   * The title of the resource header
   */
  title: PropTypes.string
};
export default ResourceHeader;

==> carbon-components-react-0.1.8.tgz: package/es/components/ResourceHeader/ResourceHeader.js <==
import React from 'react';
import PropTypes from 'prop-types';
import classNames from 'classnames';
import Button from '../Button';
import { Tools16, Stop16, Restart16 } from '@rocketsoftware/icons-react';

function renderActionButtons(type, onClick) {
  var stop = Stop16;
  var reboot = Restart16;
  var maintenance = Tools16;
  var svg;

  if (type === 'Stop') {
    svg = stop;
    return React.createElement(Button, {
      className: "bx--resource-header__button",
      onClick: onClick,
      small: true,
      renderIcon: svg,
      kind: "ghost"
    }, type);
  } else if (type === 'Reboot') {
    svg = reboot;
    return React.createElement(Button, {
      className: "bx--resource-header__button",
      onClick: onClick,
      renderIcon: svg,
      small: true,
      kind: "ghost"
    }, type);
  } else if (type === 'Maintenance') {
    svg = maintenance;
    return React.createElement(Button, {
      className: "bx--resource-header__button",
      onClick: onClick,
      small: true,
      renderIcon: svg,
      kind: "ghost"
    }, type);
  }
} // function renderTitleStatus() {
//   return (
//     <div className="bx--resource-header__status-item bx--resource-header__status-item--active">
//       Active
//     </div>
//   );
// }


function renderStatus(status) {
  return status.map(function (item, i) {
    var statusClasses = classNames({
      'bx--resource-header__status-item--active': item.isTrue
    }, 'bx--resource-header__status-item');
    return React.createElement("div", {
      key: i,
      className: statusClasses
    }, item.text);
  });
}

var ResourceHeader = function ResourceHeader(_ref) {
  var className = _ref.className,
      icon = _ref.icon,
      isActive = _ref.isActive,
      renderActions = _ref.renderActions,
      renderBreadcrumbs = _ref.renderBreadcrumbs,
      renderMaintenance = _ref.renderMaintenance,
      renderReboot = _ref.renderReboot,
      renderStop = _ref.renderStop,
      status = _ref.status,
      subtitle = _ref.subtitle,
      title = _ref.title;
  var resourceHeaderClasses = classNames('bx--resource-header', className);
  return React.createElement("header", {
    className: resourceHeaderClasses
  }, React.createElement("section", {
    className: "bx--resource-header__container"
  }, React.createElement("div", {
    className: "bx--resource-header__container--left"
  }, renderBreadcrumbs && renderBreadcrumbs(), React.createElement("div", {
    className: "bx--resource-header__content-container"
  }, icon && React.createElement("div", {
    className: "bx--resource-header__icon"
  }, icon), React.createElement("div", {
    className: "bx--resource-header__content"
  }, title && React.createElement("div", {
    className: "bx--resource-header__title"
  }, React.createElement("h3", null, title), isActive && React.createElement("div", {
    className: "bx--resource-header__status-item bx--resource-header__status-item--active"
  }, "Active")), React.createElement("div", {
    className: "bx--resource-header__subtitle"
  }, subtitle && subtitle.map(function (item, key) {
    return React.createElement("span", {
      key: key
    }, item, " \xA0");
  }))))), React.createElement("div", {
    className: "bx--resource-header__container--right"
  }, React.createElement("div", {
    className: "bx--resource-header__status"
  }, React.createElement("div", null, status && renderStatus(status))), React.createElement("div", {
    className: "bx--resource-header__actions"
  }, renderStop && renderActionButtons('Stop', renderStop), renderReboot && renderActionButtons('Reboot', renderReboot), renderMaintenance && renderActionButtons('Maintenance', renderMaintenance), renderActions && renderActions()))));
};

ResourceHeader.propTypes = {
  /**
   * The CSS class names of the resource header
   */
  className: PropTypes.string,

  /**
   * The icon to be rendered in the header.
   */
  icon: PropTypes.node,

  /**
   * `true` to show the status text next to the resource header title.
   */
  isActive: PropTypes.bool,

  /**
   * The function used to create and show an action dropdown.
   */
  renderActions: PropTypes.func,

  /**
   * The function used to create and show breadcrumbs.
   */
  renderBreadcrumbs: PropTypes.func,

  /**
   * The function used to show and attach actions to the maintenance icon
   */
  renderMaintenance: PropTypes.func,

  /**
   * The function used to show and attach actions to the reboot icon
   */
  renderReboot: PropTypes.func,

  /**
   * The function used to show and attach actions to the stop icon
   */
  renderStop: PropTypes.func,

  /**
   * The array used to show status text above the action icons
   */
  status: PropTypes.array,

  /**
   * The array used to show subtitle text below the resource header title
   */
  subtitle: PropTypes.array,

  /**
   * The title of the resource header
   */
  title: PropTypes.string
};
export default ResourceHeader;
